Learn R Programming

scmSpillover (version 0.1.1)

scm: Basic SCM function for single unit

Description

Computes synthetic control weights for a single treated unit

Usage

scm(Y, lambda = 1e-06)

Value

List containing intercept (a) and weights (b)

Arguments

Y

N x T matrix where first row is treated unit

lambda

Regularization parameter for numerical stability