powered by
Computes synthetic control weights for a single treated unit
scm(Y, lambda = 1e-06)
List containing intercept (a) and weights (b)
N x T matrix where first row is treated unit
Regularization parameter for numerical stability